@@ -7,7 +7,7 @@ import stat
 import subprocess
 import tarfile
 import textwrap
-from typing import Optional, List, FrozenSet, BinaryIO, cast
+from typing import BinaryIO, cast
 from collections.abc import Iterable, Callable
 
 from debputy.intermediate_manifest import TarMember, PathType
@@ -20,7 +20,7 @@ from debputy.util import (
     program_name,
     assume_not_none,
 )
-from debputy.version import __version__
+from debputy.version import version
 
 
 # AR header / start of a deb file for reference
@@ -54,7 +54,7 @@ class ArMember:
 
     @property
     def mtime(self) -> int:
-        return self.mtime
+        return self._mtime
 
     def write_to(self, fd: BinaryIO) -> None:
         writer = self._write_to_impl
@@ -172,7 +172,19 @@ def _xz_cmdline(
     parsed_args: argparse.Namespace | None,
 ) -> list[str]:
     compression_level = compression_rule.effective_compression_level(parsed_args)
-    cmdline = ["xz", "-T2", "-" + str(compression_level)]
+    threads_max = parsed_args.threads_max
+    cmdline = [
+        "xz",
+        f"-T+{threads_max}",
+        "-" + str(compression_level),
+        # Do not generate warnings when adjusting memory usage, nor
+        # exit with non-zero due to those not emitted warnings.
+        "--quiet",
+        "--no-warn",
+        # Do not let xz fallback to single-threaded mode, to avoid
+        # non-reproducible output.
+        "--no-adjust",
+    ]
     strategy = None if parsed_args is None else parsed_args.compression_strategy
     if strategy is None:
         strategy = "none"
@@ -282,7 +294,7 @@ def parse_args() -> argparse.Namespace:
     try:
         threads_max = int(os.environ["DPKG_DEB_THREADS_MAX"])
     except (KeyError, ValueError):
-        threads_max = None
+        threads_max = 0
 
     description = textwrap.dedent(
         """\
@@ -311,7 +323,7 @@ def parse_args() -> argparse.Namespace:
         allow_abbrev=False,
         prog=program_name(),
     )
-    parser.add_argument("--version", action="version", version=__version__)
+    parser.add_argument("--version", action="version", version=version())
     parser.add_argument(
         "package_root_dir",
         metavar="PACKAGE_ROOT_DIR",
@@ -397,9 +409,8 @@ def parse_args() -> argparse.Namespace:
         "--threads-max",
         dest="threads_max",
         default=threads_max,
-        # TODO: Support this properly
         type=int,
-        help="Ignored; accepted for compatibility",
+        help="Sets the maximum number of  threads  allowed  for  compressors  that  support  multi-threaded operations",
     )
     parser.add_argument(
         "-d",
@@ -477,7 +488,7 @@ def _ctrl_tar_members(package_root_dir: str, mtime: int) -> Iterable[TarMember]:
             )
 
 
-def parse_manifest(manifest_path: "Optional[str]") -> "List[TarMember]":
+def parse_manifest(manifest_path: str | None) -> list["TarMember"]:
     if manifest_path is None:
         _error(f"--intermediate-package-manifest is mandatory for now")
     return TarMember.parse_intermediate_manifest(manifest_path)
@@ -525,7 +536,7 @@ def pack(
     ctrl_compression: Compression,
     data_compression: Compression,
     root_dir: str,
-    package_manifest: "Optional[str]",
+    package_manifest: str | None,
     mtime: int,
     ctrl_compression_cmd: list[str],
     data_compression_cmd: list[str],
