@@ -10,7 +10,6 @@ from typing import (
 )
 from collections.abc import Sequence, Callable
 
-from debputy import __version__
 from debputy.linting.lint_util import AbortTaskError
 from debputy.lsp.lsp_features import (
     LSP_DIAGNOSTIC_HANDLERS,
@@ -24,8 +23,10 @@ from debputy.lsp.lsp_features import (
     C,
     TEXT_DOC_INLAY_HANDLERS,
     HandlerDispatchTable,
+    DOCUMENT_LINK_HANDLERS,
 )
 from debputy.util import _info, _trace_log
+from debputy.version import version
 
 if TYPE_CHECKING:
     import lsprotocol.types as types
@@ -38,7 +39,7 @@ if TYPE_CHECKING:
 
     from debputy.lsp.debputy_ls import DebputyLanguageServer
 
-    DEBPUTY_LANGUAGE_SERVER = DebputyLanguageServer("debputy", f"v{__version__}")
+    DEBPUTY_LANGUAGE_SERVER = DebputyLanguageServer("debputy", f"v{version()}")
 else:
     import debputy.lsprotocol.types as types
 
@@ -47,7 +48,7 @@ else:
         from pygls.workspace import TextDocument
         from debputy.lsp.debputy_ls import DebputyLanguageServer
 
-        DEBPUTY_LANGUAGE_SERVER = DebputyLanguageServer("debputy", f"v{__version__}")
+        DEBPUTY_LANGUAGE_SERVER = DebputyLanguageServer("debputy", f"v{version()}")
     except ImportError:
 
         class Mock:
@@ -270,6 +271,20 @@ async def _format_document(
     )
 
 
+@DEBPUTY_LANGUAGE_SERVER.feature(types.TEXT_DOCUMENT_DOCUMENT_LINK)
+async def _document_link(
+    ls: "DebputyLanguageServer",
+    params: types.DocumentLinkParams,
+) -> Optional[Sequence[types.DocumentLink]]:
+    return await _dispatch_standard_handler(
+        ls,
+        params.text_document.uri,
+        params,
+        DOCUMENT_LINK_HANDLERS,
+        "Document links request",
+    )
+
+
 async def _dispatch_standard_handler(
     ls: "DebputyLanguageServer",
     doc_uri: str,
