@@ -1,11 +1,5 @@
 import dataclasses
-from typing import (
-    TypedDict,
-    TYPE_CHECKING,
-    Generic,
-    Type,
-    Optional,
-)
+from typing import TypedDict, TYPE_CHECKING, Generic, Optional
 from collections.abc import Callable
 
 from debputy.plugin.plugin_state import current_debputy_plugin_required
@@ -14,7 +8,6 @@ from debputy.util import T
 
 if TYPE_CHECKING:
     from debputy.manifest_parser.parser_data import ParserContextData
-
     from debputy.manifest_parser.util import AttributePath
 
 
