@@ -1,4 +1,4 @@
-import collections
+import collections.abc
 import dataclasses
 from typing import (
     Dict,
@@ -111,7 +111,9 @@ def _find_package_name_prefix(
     yield main_binary_package, path.name, False, False
 
 
-def _iterate_stem_splits(basename: str) -> tuple[str, str, int]:
+def _iterate_stem_splits(
+    basename: str,
+) -> collections.abc.Iterator[tuple[str, str | None, int]]:
     stem = basename
     period_count = stem.count(".")
     yield stem, None, period_count
@@ -455,7 +457,7 @@ def classify_debian_packaging_files(
         allow_fuzzy_matches=allow_fuzzy_matches,
     )
     if main_binary_package is None:
-        return {}
+        return
     provided_files_by_key: dict[tuple[str, str, str], PackagerProvidedFile] = {}
     max_periods_in_package_name = max(name.count(".") for name in binary_packages)
     if detect_typos and CAN_DETECT_TYPOS:
@@ -495,7 +497,7 @@ def classify_debian_packaging_files(
                 continue
             provided_files_by_key[match_key] = packager_provided_file
 
-    paths2ppfs_per_package = {}
+    paths2ppfs_per_package = dict[str, dict[str, list[PackagerProvidedFile]]]()
     for packager_provided_file in provided_files_by_key.values():
         package_name = packager_provided_file.package_name
         path_name = packager_provided_file.path.path
